@@ -1,3 +1,5 @@
+from by import time as by_time, index as by_index, point as by_point
+
 class PitchTier(object):
     """A PitchTier."""
     
@@ -99,7 +101,7 @@ class PitchTier(object):
         self._indexed = True
     
     def shift_point_to_time(self, target_time, by_target, by, ignore_missing_point=False):
-        """Remove Point of the PitchTier to chosen time with chosen method."""
+        """Shift Point of the PitchTier to chosen time with chosen method."""
 
         try:
             by.by_method
@@ -111,7 +113,7 @@ class PitchTier(object):
         if point==None:
             pass
         else:
-            self.remove_point(point, pytg.by.point)
+            self.remove_point(point, by_point)
             
             self._indexed = False
             point.time = target_time
@@ -139,7 +141,7 @@ class PitchTier(object):
 
         elif by.by_method=='by_index':
             for index in range(by_target[0], by_target[1]):
-                points.append(self.get_point(index, pytg.by.index))
+                points.append(self.get_point(index, by_index))
                 
         elif by.by_method=='by_time':
             for point in self.__objects:
